@@ -1,7 +1,8 @@
 from django.urls import include, path, reverse
 from django.utils.html import format_html
+from django.utils.translation import gettext
 from django.utils.translation import gettext_lazy as _
-from django.utils.translation import gettext, ngettext
+from django.utils.translation import ngettext
 from wagtail.admin.menu import MenuItem
 from wagtail.admin.search import SearchArea
 # from wagtail.admin.site_summary import SummaryItem
